import React, { useState } from "react";
import { Form, Button } from "react-bootstrap";

const Login = () => {
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [isValid, setIsValid] = useState(false);

  const checkFormValidity = () => {
    // Simple validation for demonstration purposes
    const isValid = email !== "" && password !== "";
    setIsValid(isValid);
  };

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    // Update state based on the input field name
    switch (name) {
      case "email":
        setEmail(value);
        break;
      case "password":
        setPassword(value);
        break;
      default:
        break;
    }
  };

  const handleSubmit = async (e) => {
    e.preventDefault();

    try {
      const response = await fetch("http://localhost:4000/users/login", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          email,
          password,
        }),
      });

      if (response.ok) {
        alert("Thank you for logging in");
        console.log("Login success")
        // Handle successful login, e.g., redirect to another page
      } else {
        alert("Unsucessful login");
        // Handle invalid credentials, e.g., show an error message
      }
    } catch (error) {
      console.error("Error during login:", error);
      // Handle other errors, e.g., network issues
    }
  };

  return (
    <Form onSubmit={handleSubmit}>
      <h1 className="my-5 text-center">Login</h1>
      <Form.Group>
        <Form.Label>Email Address:</Form.Label>
        <Form.Control
          type="email"
          placeholder="Enter Email"
          required
          name="email"
          value={email}
          onChange={(e) => {
            handleInputChange(e);
            checkFormValidity();
          }}
        />
      </Form.Group>
      <Form.Group>
        <Form.Label>Password:</Form.Label>
        <Form.Control
          type="password"
          placeholder="Enter Password"
          required
          name="password"
          value={password}
          onChange={(e) => {
            handleInputChange(e);
            checkFormValidity();
          }}
        />
      </Form.Group>
      <Button variant="success" type="submit" disabled={!isValid}>
        Login
      </Button>
    </Form>
  );
};

export default Login;
